@@ -459,8 +459,12 @@ class SmartCard(object):
 
 		# initialize.
 		response = utils.__default_response__()
-		if pin == None: pin = utils.__generate_pincode__(characters=6)
-		if puk == None: puk = utils.__generate_pincode__(characters=8)
+		if pin == None: 
+			pin = utils.__generate_pincode__(characters=6)
+		elif len(pin) != 6: return r3sponse.error_response("The pin code must be a six character integer code.")
+		if puk == None: 
+			puk = utils.__generate_pincode__(characters=8)
+		elif len(puk) != 8: return r3sponse.error_response("The puk code must be a eight character integer code.")
 		info = {
 			"pin":pin,
 			"puk":puk,
