@@ -263,35 +263,61 @@ class Config(object):
 		if sudo: sudo_option = "sudo "
 		ssh_dir = Formats.FilePath(f"{HOME_BASE}/{username}/.ssh/", check_existance=False)
 		auth_keys = Formats.FilePath(f"{HOME_BASE}/{username}/.ssh/authorized_keys", check_existance=False)
+
+		# checks.
+		if not ssh_dir.exists(sudo=sudo):
+			ssh_dir.create(
+				directory=True,
+				permission=770,
+				owner=username,
+				group=None,
+				sudo=sudo,)
+		if not auth_keys.exists(sudo=sudo):
+			auth_keys.create(
+				directory=False,
+				data="",
+				permission=770,
+				owner=username,
+				group=None,
+				sudo=sudo,)
+
 		ssh_dir.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
 		auth_keys.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
+		auth_keys.ownership.set(owner=OWNER, sudo=sudo)
+		ssh_dir.ownership.set(owner=OWNER, sudo=sudo)
 
 		# get output.
 		command = []
-		if sudo: command += ["sudo"]
+		if sudo: command = ["sudo"]
 		output = utils.__execute__(command + ["cat", f"{HOME_BASE}/{username}/.ssh/authorized_keys"], return_format="array")
-		
+		print("AUTHORIZED KEYS:  ",output)
 		# handle ssh dir not installed.
 		try:
 			if "No such file or directory" in output[0]:
+				print('NO SUCH FILLEEELELELEELE')
 				ssh_dir.check(
 					directory=True,
 					permission=770,
 					owner=username,
-					group="administrator",
+					group=None,
 					sudo=sudo,)
 				auth_keys.check(
 					data="",
 					permission=770,
 					owner=username,
-					group="administrator",
+					group=None,
 					sudo=sudo,)
+				ssh_dir.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
+				auth_keys.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
+				auth_keys.ownership.set(owner=OWNER, sudo=sudo)
+				ssh_dir.ownership.set(owner=OWNER, sudo=sudo)
 				output = []
-		except IndexError: a=1
+		except IndexError: output = []
 
 		# check if already present.
 		for key in public_keys:
 			if key.replace("\n", "") not in output:
+				key = key.replace('\n','')
 				os.system(f"{sudo_option}echo '{key}' >> {HOME_BASE}/{username}/.ssh/authorized_keys")
 
 		# check if added.
@@ -300,12 +326,16 @@ class Config(object):
 			if key.replace("\n", "") not in output:
 				auth_keys.permission.set(permission=600, sudo=sudo)
 				ssh_dir.permission.set(permission=700, sudo=sudo)
+				auth_keys.ownership.set(owner=username, sudo=sudo)
+				ssh_dir.ownership.set(owner=username, sudo=sudo)
 				key = key.replace("\n", "")
 				return r3sponse.error_response(f'Failed to enable public key [{key}].')
 	
 		# set correct permission.
 		auth_keys.permission.set(permission=600, sudo=sudo)
 		ssh_dir.permission.set(permission=700, sudo=sudo)
+		auth_keys.ownership.set(owner=username, sudo=sudo)
+		ssh_dir.ownership.set(owner=username, sudo=sudo)
 
 		# success.
 		return r3sponse.success_response(f'Successfully enabled {len(public_keys)} public key(s).')
@@ -318,8 +348,28 @@ class Config(object):
 		sudo = OWNER != username
 		ssh_dir = Formats.FilePath(f"{HOME_BASE}/{username}/.ssh/", check_existance=False)
 		auth_keys = Formats.FilePath(f"{HOME_BASE}/{username}/.ssh/authorized_keys", check_existance=False)
+
+		# checks.
+		if not ssh_dir.exists(sudo=sudo):
+			ssh_dir.create(
+				directory=True,
+				permission=770,
+				owner=username,
+				group=None,
+				sudo=sudo,)
+		if not auth_keys.exists(sudo=sudo):
+			auth_keys.create(
+				directory=False,
+				data="",
+				permission=770,
+				owner=username,
+				group=None,
+				sudo=sudo,)
+
 		ssh_dir.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
 		auth_keys.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
+		auth_keys.ownership.set(owner=OWNER, sudo=sudo)
+		ssh_dir.ownership.set(owner=OWNER, sudo=sudo)
 
 		# get output.
 		command = []
@@ -333,20 +383,25 @@ class Config(object):
 					directory=True,
 					permission=770,
 					owner=username,
-					group="administrator",
+					group=None,
 					sudo=sudo,)
 				auth_keys.check(
 					data="",
 					permission=770,
 					owner=username,
-					group="administrator",
+					group=None,
 					sudo=sudo,)
+				ssh_dir.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
+				auth_keys.permission.set(permission=770, sudo=sudo, silent=True) # silent for when non existant.
+				auth_keys.ownership.set(owner=OWNER, sudo=sudo)
+				ssh_dir.ownership.set(owner=OWNER, sudo=sudo)
 				output = []
 		except IndexError: a=1
 
 		# check if already present.
 		new_keys = ""
 		for key in output:
+			key = key.replace("\n", "")
 			if key.replace("\n", "") not in public_keys:
 				if new_keys == "":
 					new_keys = key+"\n"
@@ -357,15 +412,19 @@ class Config(object):
 		# check if deleted.
 		output = utils.__execute__(command + ["cat", f"{HOME_BASE}/{username}/.ssh/authorized_keys"], return_format="array")
 		for key in public_keys:
-			if key.replace("\n", "") in output:
+			key = key.replace("\n", "")
+			if key in output:
 				auth_keys.permission.set(permission=600, sudo=sudo)
 				ssh_dir.permission.set(permission=700, sudo=sudo)
-				key = key.replace("\n", "")
+				auth_keys.ownership.set(owner=username, sudo=sudo)
+				ssh_dir.ownership.set(owner=username, sudo=sudo)
 				return r3sponse.error_response(f'Failed to disable public key [{key}].')
 
 		# set correct permission.
 		auth_keys.permission.set(permission=600, sudo=sudo)
 		ssh_dir.permission.set(permission=700, sudo=sudo)
+		auth_keys.ownership.set(owner=username, sudo=sudo)
+		ssh_dir.ownership.set(owner=username, sudo=sudo)
 
 		# success.
 		return r3sponse.success_response(f'Successfully disabled {len(public_keys)} public key(s).')
